==> haskell-vector-sized-1.6.1-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-sized
version:              1.6.1
visibility:           public
id:                   vector-sized-1.6.1-AGnqv8gNX3eU4YGGJw30L
key:                  vector-sized-1.6.1-AGnqv8gNX3eU4YGGJw30L
license:              BSD-3-Clause
copyright:            2016 Ellie Hermaszewska
maintainer:           whats.our.vector.victor@monoid.al
author:               Ellie Hermaszewska
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  6d51775928beff50bfd09a5fa0f268d4
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.6.1-AGnqv8gNX3eU4YGGJw30L
depends:
    adjunctions-4.4.2-Fr74Xib0o8DC69CcKjlWIB base-4.17.2.1
    binary-0.8.9.1 comonad-5.0.8-FaXCdIH358gBTaN3fXTS5x deepseq-1.4.8.0
    distributive-0.6.2.1-2YiBzgLXCd2kHPlGPsZiv
    finite-typelits-0.2.0.0-HRcMPJhrwuS7iLVfyEaDyw
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    indexed-list-literals-0.2.1.3-FxXM2wo0CNUH9xZHVKOm2i
    indexed-traversable-0.1.4-EiyQIsHWfilLwzPb8OdnEq
    primitive-0.8.0.0-CgxKCR9ULfZ73CnNdOTvCD
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-sized-1.6.1-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-sized
version:              1.6.1
visibility:           public
id:                   vector-sized-1.6.1-Elx5vH3gb4q9CYMaDJVzcH
key:                  vector-sized-1.6.1-Elx5vH3gb4q9CYMaDJVzcH
license:              BSD-3-Clause
copyright:            2016 Ellie Hermaszewska
maintainer:           whats.our.vector.victor@monoid.al
author:               Ellie Hermaszewska
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  4bdd08d2fb2270c96b14cba684bfd015
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-sized-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.6.1-Elx5vH3gb4q9CYMaDJVzcH
depends:
    adjunctions-4.4.2-ES99QxLRyYYHaownA1PAtP base-4.17.2.1
    binary-0.8.9.1 comonad-5.0.8-AikjgOvrhZ0DSXgM6149OA deepseq-1.4.8.0
    distributive-0.6.2.1-2YiBzgLXCd2kHPlGPsZiv
    finite-typelits-0.2.0.0-HRcMPJhrwuS7iLVfyEaDyw
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    indexed-list-literals-0.2.1.3-FxXM2wo0CNUH9xZHVKOm2i
    indexed-traversable-0.1.4-FY1aejevjNII752FjHavha
    primitive-0.8.0.0-CgxKCR9ULfZ73CnNdOTvCD
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
